pub struct SyntheticShape {Show 13 fields
pub air_name: String,
pub log_height: usize,
pub preprocessed_width: usize,
pub cached_main_widths: Vec<usize>,
pub common_main_width: usize,
pub after_challenge_widths: Vec<usize>,
pub num_constraints: usize,
pub num_interactions: usize,
pub num_distinct_buses: usize,
pub max_constraint_degree: usize,
pub interaction_message_lens: Vec<usize>,
pub interaction_count_weights: Vec<u32>,
pub occurrences: usize,
}Expand description
One entry in a shape atlas — shape statistics for a single AIR
observed in the captured profile, deduplicated and counted by
scripts/analyze_profile.py.
Fields
air_name: Stringlog_height: usizepreprocessed_width: usizecached_main_widths: Vec<usize>common_main_width: usizeafter_challenge_widths: Vec<usize>num_constraints: usizenum_interactions: usizenum_distinct_buses: usizemax_constraint_degree: usizeinteraction_message_lens: Vec<usize>Per-interaction message length. Schema v2 atlases populate this; older atlases leave it empty and a heuristic is used.
interaction_count_weights: Vec<u32>Per-interaction count_weight (logup soundness param).
Schema v2 atlases populate this; older atlases leave it empty.
occurrences: usizeTrait Implementations
Sourceimpl Clone for SyntheticShape
impl Clone for SyntheticShape
Sourcefn clone(&self) -> SyntheticShape
fn clone(&self) -> SyntheticShape
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SyntheticShape
impl Debug for SyntheticShape
Sourceimpl<'de> Deserialize<'de> for SyntheticShape
impl<'de> Deserialize<'de> for SyntheticShape
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more